@@ -174,7 +174,8 @@ Gtk::Widget* Widget::get_controller_by_port(uint32_t port_index)
 }
 
 Widget::Widget(Glib::ustring plugname):
-plug_name(plugname)
+plug_name(plugname),
+logo("Live Looper")
 {
   for (uint32_t i = 1;i<5;i++) {
     m_paintbox[i].property_paint_func() = "box_uni_2_expose";
@@ -268,6 +269,17 @@ plug_name(plugname)
   m_vbox[2].pack_start(m_hbox[2]);
   m_vbox[3].pack_start(m_hbox[3]);
   m_vbox[4].pack_start(m_hbox[4]);
+  // modify logo layout
+  Pango::FontDescription font_desc = logo.get_style()->get_font();
+  font_desc.set_size(int(14*Pango::SCALE));
+  font_desc.set_weight(Pango::WEIGHT_BOLD);
+  logo.modify_font(font_desc);
+  m_hbox1_.set_spacing(64);
+  logo.set_name("logo");
+  m_vbox[8].pack_start(m_hbox1_, Gtk::PACK_SHRINK);
+  m_hbox1_.pack_start(m_vbox1_, Gtk::PACK_EXPAND_PADDING);
+  m_hbox1_.pack_end(m_vbox2_, Gtk::PACK_SHRINK);
+  m_hbox1_.pack_end(logo, Gtk::PACK_SHRINK);
   // and controller box on top
   m_vbox[8].pack_start(m_hbox[0], Gtk::PACK_SHRINK);
   // put boxed controllers into controller box
@@ -516,7 +528,7 @@ void Widget::make_switch_box(Gtk::Box *box,
     regler->cp_set_var("no_log");
     regler->set_name(plug_name);
     regler->set_base_name( basename );
-    regler->set_relief(Gtk::RELIEF_NONE);
+    //regler->set_relief(Gtk::RELIEF_NONE);
     box->pack_start(*regler,Gtk::PACK_SHRINK);
     regler->signal_toggled().connect(sigc::bind(sigc::mem_fun(
         *this, &Widget::on_value_changed), port_name));
@@ -538,7 +550,7 @@ void Widget::make_reset_switch_box(Gtk::Box *box,
     regler->cp_set_var("no_log");
     regler->set_name(plug_name);
     regler->set_base_name( basename );
-    regler->set_relief(Gtk::RELIEF_NONE);
+    //regler->set_relief(Gtk::RELIEF_NONE);
     box->pack_start(*regler,Gtk::PACK_SHRINK);
     regler->signal_toggled().connect(sigc::bind(sigc::mem_fun(
         *this, &Widget::on_value_changed), port_name));
@@ -579,7 +591,7 @@ void Widget::make_radio_switch_box(Gtk::Box *box,
     regler->cp_set_var("no_log");
     regler->set_name(plug_name);
     regler->set_base_name( basename );
-    regler->set_relief(Gtk::RELIEF_NONE);
+    //regler->set_relief(Gtk::RELIEF_NONE);
     box->pack_start(*regler,Gtk::PACK_SHRINK);
     regler->signal_toggled().connect(sigc::bind(sigc::mem_fun(
         *this, &Widget::on_value_changed), port_name));
