@@ -1535,8 +1535,237 @@ void ContrastConvolver::run_contrast(int count, float *input0, float *output0, P
  ** class DrumSequencer
  */
 
-#include "gx_drumseq.cc"
+#include "faust/drumseq.cc"
 
+static const char* seq_groups[] = {
+	"hat_closed.dsp", N_("DrumSequencer"),
+	"kick.dsp", N_("DrumSequencer"),
+	"snare.dsp", N_("DrumSequencer"),
+	"tom.dsp", N_("DrumSequencer"),
+	"sequencer", N_("DrumSequencer"),
+	0
+};
+
+DrumSequencer::DrumSequencer(ParamMap& param_)
+	: PluginDef(), 
+	  Vectom(0),
+	  Vectom1(0),
+	  Vectom2(0),
+	  Veckick(0),
+	  Vecsnare(0),
+	  Vechat(0),
+	  param(param_),
+	  tomset(),
+	  tomp(0),
+	  tomset1(),
+	  tomp1(0),
+	  tomset2(),
+	  tomp2(0),
+	  snareset(),
+	  snarep(0),
+	  hatset(),
+	  hatp(0),
+	  kickset(),
+	  kickp(0),
+	  plugin() {
+	version = PLUGINDEF_VERSION;
+	flags = 0;
+	id = "seq";
+	name = N_("DrumSequencer");
+	groups = seq_groups;
+	description = N_("Simple Drum Step Sequencer"); // description (tooltip)
+	category = N_("Misc");       // category
+	shortname = N_("Drum");     // shortname
+	mono_audio = compute_static;
+	stereo_audio = 0;
+	set_samplerate = init_static;
+	activate_plugin = 0;
+	register_params = register_params_static;
+	delete_instance = del_instance;
+	plugin = this;
+}
+
+DrumSequencer::~DrumSequencer() {
+}
+
+inline void DrumSequencer::init(unsigned int samplingFreq)
+{
+	fSamplingFreq = samplingFreq;
+	counter = 0;
+	step = 0;
+	step_orig = 0;
+	fSlow1 = 0.0;
+	fSlow3 = 0.0;
+	fSlow5 = 0.0;
+	fSlow7 = 0.0;
+	fSlow18 = 150.0;
+	position = 0.0;
+	drums.init(samplingFreq);
+}
+
+void DrumSequencer::init_static(unsigned int samplingFreq, PluginDef *p)
+{
+	static_cast<DrumSequencer*>(p)->init(samplingFreq);
+}
+
+int DrumSequencer::min_seq_size(){
+	int i = min(min(min(Vectom.size(),Veckick.size()),min(Vechat.size(),Vecsnare.size())),min(Vectom1.size(),Vectom2.size()));
+	return i-1;
+}
+
+void DrumSequencer::reset_tom() {
+	Vectom = tomset.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void DrumSequencer::reset_tom1() {
+	Vectom1 = tomset1.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void DrumSequencer::reset_tom2() {
+	Vectom2 = tomset2.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void DrumSequencer::reset_kick() {
+	Veckick = kickset.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void DrumSequencer::reset_hat() {
+	Vechat = hatset.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void DrumSequencer::reset_snare() {
+	Vecsnare = snareset.getseqline() ;
+	seq_size = min_seq_size();
+}
+
+void always_inline DrumSequencer::compute(int count, FAUSTFLOAT *input0, FAUSTFLOAT *output0)
+{
+	double 	fSlow15 = (60.0/double(fsliderbpm*ftact))*fSamplingFreq;
+	counter += count;
+	int iSlow15 = (int)fSlow15;
+	// beat
+	if (counter >= iSlow15) {
+		int istep = (int)step;
+		fSlow1 = double(Vecsnare[istep]);
+		// disable hat when sequencer runs to fast
+		if (iSlow15 > 4800) {
+			fSlow3 = double(Vechat[istep]);
+		}
+		fSlow5 = double(Veckick[istep]);
+        // only one tom at time
+		if (Vectom2[istep]) {
+			fSlow7 = double(Vectom2[istep]);
+			fSlow18 = 150.0;
+			fSlow20 = fSlow16;
+		} else if (Vectom1[istep]) {
+			fSlow7 = double(Vectom1[istep]);
+			fSlow18 = 128.0;
+			fSlow20 = fSlow14;
+		} else if(Vectom[istep]) {
+			fSlow7 = double(Vectom[istep]);
+			fSlow18 = 90.0;
+			fSlow20 = fSlow12;
+		}
+		int m = ftact;
+		int r = rand()%(m+1 - (-m))+ (-m);
+		counter = 0; //int(r*fsliderhum);
+		
+		if (step<seq_size) step = fmin(seq_size,fmax(0,step + 1.0 + int(r*fsliderhum)));
+		else step = 0.0;
+		if (step_orig<seq_size) step_orig += 1.0;
+		else step_orig = 0.0;
+		double ph1 = 2300.0/seq_size;
+		position = fmin(2300,fmax(0,(step*ph1)));
+	} else {
+		fSlow1 = 0.0;
+		fSlow3 = 0.0;
+		fSlow5 = 0.0;
+		fSlow7 = 0.0;
+	}
+	drums.compute(count,input0,output0);
+}
+
+void __rt_func DrumSequencer::compute_static(int count, FAUSTFLOAT *input0, FAUSTFLOAT *output0, PluginDef *p)
+{
+	static_cast<DrumSequencer*>(p)->compute(count, input0, output0);
+}
+
+int DrumSequencer::register_par(const ParamReg& reg)
+{
+	reg.registerNonMidiFloatVar("seq.hat_closed.dsp.gate",&fSlow3, false, true, 0.0, 0.0, 1.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.kick.dsp.gate",&fSlow5, false, true, 0.0, 0.0, 1.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.snare.dsp.gate",&fSlow1, false, true, 0.0, 0.0, 1.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.tom.dsp.gate",&fSlow7, false, true, 0.0, 0.0, 1.0, 1.0);
+	reg.registerNonMidiSharedVar("seq.tom.dsp.Gainf",&fSlow20, false, true, -2e+01, -6e+01, 4e+01, 0.1);
+	reg.registerVar("seq.tom.dsp.Gain","","S",N_("Volume level in decibels"),&fSlow12, -2e+01, -6e+01, 4e+01, 0.1);
+	reg.registerVar("seq.tom.dsp.Gain1","","S",N_("Volume level in decibels"),&fSlow14, -2e+01, -6e+01, 4e+01, 0.1);
+	reg.registerVar("seq.tom.dsp.Gain2","","S",N_("Volume level in decibels"),&fSlow16, -2e+01, -6e+01, 4e+01, 0.1);
+	reg.registerNonMidiFloatVar("seq.tom.dsp.freq",&fSlow18, false, true, 9e+01, 9e+01, 1.5e+02, 1.0);
+	reg.registerVar("seq.bpm","","S",N_("Beats per Minute"),&fsliderbpm, 120, 24, 360, 1);
+	static const value_pair ftact_values[] = {{"1/4"},{"2/4"},{"3/4"},{"4/4"},{0}};
+	reg.registerEnumVar("seq.tact","","S",N_("select tact"),ftact_values,&ftact, 4.0, 1.0, 4.0, 1.0);
+	reg.registerVar("seq.asequences","","S",N_("Number of Sequences"),&fsec, 24.0, 24.0, 240.0, 4.0);
+	reg.registerVar("seq.hum","","B",N_("Randomize Sequence"),&fsliderhum, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.npreset","","BO",N_("Load next unit preset"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.ppreset","","BO",N_("Load previous unit preset"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.pos",&position, false, true, 0.0, 0.0, 2300.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.step",&step, false, true, 0.0, 0.0, 240.0, 1.0);
+	reg.registerNonMidiFloatVar("seq.step_orig",&step_orig, false, true, 0.0, 0.0, 240.0, 1.0);
+	reg.registerVar("seq.set_step","","BO",N_("Set stepper one Beat back"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.set_fstep","","BO",N_("Set stepper one Beat forward"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.set_sync","","BO",N_("Set stepper back on Beat "),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.reset_step","","BO",N_("Set stepper one Start"),0, 0.0, 0.0, 1.0, 1.0);
+	reg.registerVar("seq.follow","","BO",N_("follow playhead"),0, 0.0, 0.0, 1.0, 1.0);
+	for (int i=0; i<24; i++) Vectom.push_back(0);
+	for (int i=0; i<24; i++) Vectom1.push_back(0);
+	for (int i=0; i<24; i++) Vectom2.push_back(0);
+	for (int i=0; i<24; i++) Veckick.push_back(0);
+	for (int i=0; i<24; i++) Vechat.push_back(0);
+	for (int i=0; i<24; i++) Vecsnare.push_back(0);
+	seq_size = min_seq_size();
+	tomp = SeqParameter::insert_param(param, "seq.sequencer.tom", &tomset);
+	tomp1 = SeqParameter::insert_param(param, "seq.sequencer.tom1", &tomset1);
+	tomp2 = SeqParameter::insert_param(param, "seq.sequencer.tom2", &tomset2);
+	snarep = SeqParameter::insert_param(param, "seq.sequencer.snare", &snareset);
+	hatp = SeqParameter::insert_param(param, "seq.sequencer.hat", &hatset);
+	kickp = SeqParameter::insert_param(param, "seq.sequencer.kick", &kickset);
+	tomp->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_tom)));
+	tomp1->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_tom1)));
+	tomp2->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_tom2)));
+	snarep->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_snare)));
+	hatp->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_hat)));
+	kickp->signal_changed().connect(
+	sigc::hide(
+		sigc::mem_fun(this, &DrumSequencer::reset_kick)));
+
+	drums.register_par(reg);
+	return 0;
+}
+
+int DrumSequencer::register_params_static(const ParamReg& reg)
+{
+	return static_cast<DrumSequencer*>(reg.plugin)->register_par(reg);
+}
+
+void DrumSequencer::del_instance(PluginDef *p)
+{
+	delete static_cast<DrumSequencer*>(p);
+}
 
 /****************************************************************************
 *
