@@ -108,10 +108,30 @@ static struct midi_std_init {
     {127, "Poly On (Mono Off)"},
 };
 
+string MidiStandardControllers::midi_to_note(int ctr) {
+	static const char* notes[12] = {"C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B" };
+    int octave = (ctr / 12) - 1;
+    ostringstream b;
+    b << octave;
+    string p = b.str().substr(0, 1);
+    int index = (ctr % 12);
+    string note = notes[index];
+    return note + p;
+}
+
+string MidiStandardControllers::ctr_desc(int ctr) {
+    string p = midi_to_note(ctr-200);
+    return  "Note On ( " + p + " )";
+ }
+
 MidiStandardControllers::MidiStandardControllers() {
     for (unsigned int i = 0; i < sizeof(midi_std_itab)/sizeof(midi_std_itab[0]); i++) {
         m.insert(pair<int, modstring>(midi_std_itab[i].ctrl, modstring(midi_std_itab[i].name)));
     }
+    for (unsigned int i = 0; i < 127; i++) {
+        const int mm = i + 200;
+        m.insert(pair<int, modstring>(mm, modstring(ctr_desc(mm).c_str())));
+    }
 }
 
 void MidiStandardControllers::replace(int ctr, const string& name) {
@@ -277,7 +297,7 @@ MidiController *MidiController::readJSON(gx_system::JsonParser& jp, ParamMap& pm
     return new MidiController(pm, lower, upper, toggle, toggle_behaviour);
 }
 
-bool MidiController::set_midi(int n, int last_value) {
+bool MidiController::set_midi(int n, int last_value, bool update) {
     bool ret = false;
     if (param->get_midi_blocked()) return ret;
     if (toggle) {
@@ -297,9 +317,11 @@ bool MidiController::set_midi(int n, int last_value) {
             case Parameter::toggle_type::Constant: {
                 if (n == last_value || last_value == -1) {
                     if (param->on_off_value()) {
-                        ret = param->midi_set(0, n, _lower, _upper);
+                        if (!update) ret = param->midi_set(0, n, _lower, _upper);
+                        else ret = param->midi_set(127, n, _lower, _upper);
                     } else {
-                        ret = param->midi_set(127, n, _lower, _upper);
+                        if (!update) ret = param->midi_set(127, n, _lower, _upper);
+                        else ret = param->midi_set(0, n, _lower, _upper);
                     }
                 }
                 break;
@@ -311,7 +333,7 @@ bool MidiController::set_midi(int n, int last_value) {
         //fprintf(stderr,"%f \n",double(n * double(double(n+1.)/128)));
         ret = param->midi_set(n, 127, _lower, _upper);
     }
-    param->trigger_changed();
+    //param->trigger_changed();
     return ret;
 }
 
@@ -479,6 +501,7 @@ MidiControllerList::MidiControllerList()
       pgm_chg(),
       mute_chg(),
       bank_chg(),
+      val_chg(),
       changed(),
       new_program(),
       new_mute_state(),
@@ -491,8 +514,9 @@ MidiControllerList::MidiControllerList()
     pgm_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_pgm_chg));
     mute_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_mute_chg));
     bank_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_bank_chg));
-    Glib::signal_timeout().connect(
-	sigc::mem_fun(this, &MidiControllerList::check_midi_values), 60);
+    val_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_val_chg));
+   // Glib::signal_timeout().connect(
+	// sigc::mem_fun(this, &MidiControllerList::check_midi_values), 60);
 }
 
 bool MidiControllerList::check_midi_values() {
@@ -517,13 +541,34 @@ bool MidiControllerList::check_midi_values() {
     return true;
 }
 
+void MidiControllerList::on_val_chg() {
+    static int saved_values[ControllerArray::array_size];
+    for (unsigned int n = 0; n < ControllerArray::array_size; ++n) {
+        if (changed_midi_control_value[n]) {
+            changed_midi_control_value[n] = 0;
+            saved_values[n] = last_midi_control_value[n];
+            midi_value_changed(n, saved_values[n]);
+            if (!get_config_mode()) {
+                midi_controller_list& ctr_list = map[n];
+                for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
+                    if (i->is_toggle()
+                        && i->toggle_behaviour() == Parameter::toggle_type::Constant) {
+                        midi_value_changed(n, i->getParameter().on_off_value() * 127);
+                    }
+                    i->trigger_changed();
+                }
+            }
+        }
+    }
+}
+
 /** update all controlled parameters with last received value from MIDI controller ctr. */
 void MidiControllerList::update_from_controller(int ctr) {
     int v = get_last_midi_control_value(ctr);
     if (v >= 0) {
 	midi_controller_list& cl = map[ctr];
 	for (midi_controller_list::iterator i = cl.begin(); i != cl.end(); ++i) {
-	    i->set_midi(v, v);
+	    i->set_midi(v, v, true);
 	}
     }
 }
@@ -615,7 +660,7 @@ void MidiControllerList::set_ctr_val(int ctr, int val) {
     } else {
         midi_controller_list& ctr_list = map[ctr];
         for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
-            i->set_midi(val, get_last_midi_control_value(ctr));
+            i->set_midi(val, get_last_midi_control_value(ctr), false);
         }
     }
     MidiControllerList::set_last_midi_control_value(ctr, val);
@@ -697,6 +742,7 @@ void MidiControllerList::process_trans(int transport_state) {
         }
     }
     MidiControllerList::set_last_midi_control_value(24, val);
+    val_chg();
 }
 
 // ----- jack process callback for the midi input
@@ -718,8 +764,13 @@ void MidiControllerList::compute_midi_in(void* midi_input_port_buf, void *arg) {
 				 bank_chg();
 			} else {
 				set_ctr_val(in_event.buffer[1], in_event.buffer[2]);
+				val_chg();
 			}
-        } else if ((in_event.buffer[0] ) > 0xf0) {   // midi clock
+        } else if ((in_event.buffer[0] & 0xf0) == 0x90) {   // Note On
+			set_ctr_val(in_event.buffer[1]+200, 1);
+			val_chg();
+			//fprintf(stderr,"Note On %i", (int)in_event.buffer[1]);
+		} else if ((in_event.buffer[0] ) > 0xf0) {   // midi clock
             if ((in_event.buffer[0] ) == 0xf8) {   // midi beat clock
                 clock_gettime(CLOCK_MONOTONIC, &ts1);
                 gx_jack::GxJack& jack = *static_cast<gx_jack::GxJack*>(arg);
@@ -728,13 +779,16 @@ void MidiControllerList::compute_midi_in(void* midi_input_port_buf, void *arg) {
                         (1000000000.0/(double)(sr/(double)in_event.time));
                 if (mp.time_to_bpm(time0, &bpm_)) {
                     set_bpm_val(bpm_);
+                    val_chg();
                 }
             } else if ((in_event.buffer[0] ) == 0xfa) {   // midi clock start
                 set_ctr_val(23, 127);
+                val_chg();
             } else if ((in_event.buffer[0] ) == 0xfb) {   // midi clock continue
                //  set_ctr_val(23, 127);
             } else if ((in_event.buffer[0] ) == 0xfc) {   // midi clock stop
                 set_ctr_val(23, 0);
+                val_chg();
             } else if ((in_event.buffer[0] ) == 0xf2) {   // midi clock position
               // not implemented 
               //  set_ctr_val(24,(in_event.buffer[2]<<7) | in_event.buffer[1]);
@@ -801,6 +855,14 @@ string param_group(const string& group_id, bool nowarn) {
     }
 }
 
+bool ParameterGroups::group_exist(const string& id) {
+    if (groups.find(id) == groups.end()) {
+	return false;
+    } else {
+	return true;
+    }
+}
+
 /****************************************************************
  ** Parameter
  */
