@@ -926,6 +926,17 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 	serv.settings.save(*serv.settings.banks.get_file(params[0]->getString()), params[1]->getString());
     }
 
+    PROCEDURE(plugin_preset_list_sync_set) {
+	gx_system::JsonStringWriter jw;
+	serv.jwc = &jw;
+	send_notify_begin(jw, "set");
+	serv.settings.plugin_preset_list_sync_set(
+	    serv.jack.get_engine().pluginlist.find_plugin(params[0]->getString())->get_pdef(),
+	    params[1]->getInt(), params[2]->getString());
+	serv.jwc = 0;
+	serv.broadcast(jw, f_parameter_change_notify);
+    }
+
     PROCEDURE(plugin_preset_list_set) {
 	gx_system::JsonStringWriter jw;
 	serv.jwc = &jw;
@@ -1055,6 +1066,10 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 	serv.settings.load_online_presets();
     }
 
+    PROCEDURE(create_default_scratch_preset) {
+	serv.settings.create_default_scratch_preset();
+    }
+
     PROCEDURE(sendcc) {
 	serv.jack.send_midi_cc(params[0]->getInt(),params[1]->getInt(),params[2]->getInt(),params[3]->getInt());
     }
@@ -1148,6 +1163,17 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 	    params[0]->getInt(), serv.jack.get_jack_bs());
     }
 
+    PROCEDURE(insert_param) {
+	gx_engine::ParamMap& param = serv.settings.get_param();
+    const Glib::ustring& id = params[0]->getString();
+    const Glib::ustring& tb = params[1]->getString();
+    if (!param.hasId(id)) {
+        gx_engine::BoolParameter& sp = param.reg_par(
+          id, tb, (bool*)0, false, false)->getBool();
+        sp.setSavable(false);
+        }
+    }
+
     END_FUNCTION_SWITCH(cerr << "Method not found: " << mn->name << endl; assert(false));
 }
 
