@@ -36,6 +36,7 @@ class LadspaDsp: public PluginDef {
 private:
     static void init(unsigned int samplingFreq, PluginDef *plugin);
     static void mono_process(int count, float *input, float *output, PluginDef *plugin);
+    static void to_mono_process(int count, float *input, float *output, PluginDef *plugin);
     static void stereo_process(int count, float *input1, float *input2, float *output1, float *output2, PluginDef *plugin);
     static int activate(bool start, PluginDef *plugin);
     static int registerparam(const ParamReg& reg);
@@ -47,6 +48,7 @@ private:
     LADSPA_Handle instance;
     LADSPA_Data *ports;
     Glib::ustring name_str;
+    Glib::ustring dest_str;
     const plugdesc *pd;
     bool is_activated;
     void connect(int tp, int i, float *v);
@@ -56,8 +58,10 @@ private:
     std::string idd;
     inline void mono_dry_wet(int count, float *input0, float *input1, float *output0);
     inline void stereo_dry_wet(int count, float *input0, float *input1, float *input2, float *input3, float *output0, float *output1);
+    inline void down_to_mono(int count, float *input0, float *input1, float *output0);
+    inline void up_to_stereo(int count, float *input0, float *output0, float *output1);
     std::string make_id(const paradesc& p);
-    LadspaDsp(const plugdesc *plug, void *handle_, const LADSPA_Descriptor *desc_, bool mono);
+    LadspaDsp(const plugdesc *plug, void *handle_, const LADSPA_Descriptor *desc_, bool mono, bool to_mono);
     ~LadspaDsp();
 public:
     static LadspaDsp *create(const plugdesc *plug);
@@ -115,12 +119,14 @@ LadspaDsp *LadspaDsp::create(const plugdesc *plug) {
 	}
     }
     bool mono;
+    bool to_mono = false;
     if (num_inputs == 1 && num_outputs == 1) {
 	mono = true;
     } else if (num_inputs == 2 && num_outputs == 2) {
 	mono = false;
+	if (plug->stereo_to_mono) to_mono = true;
     } else {
-	gx_print_error(
+ 	gx_print_error(
 	    "ladspaloader",ustring::compose(
 		_("cannot use ladspa plugin %1 with %2 inputs and %3 outputs"),
 		desc->Label, num_inputs, num_outputs));
@@ -128,23 +134,32 @@ LadspaDsp *LadspaDsp::create(const plugdesc *plug) {
 	handle = 0;
 	return NULL;
     }
-    return new LadspaDsp(plug, handle, desc, mono);
+    
+    LadspaDsp* self = new LadspaDsp(plug, handle, desc, mono, to_mono);
+    PluginDef& pl = *static_cast<PluginDef*>(self);
+    pl.flags |=PGNI_IS_LADSPA;    
+    return self;
 }
 
-LadspaDsp::LadspaDsp(const plugdesc *plug, void *handle_, const LADSPA_Descriptor *desc_, bool mono)
+LadspaDsp::LadspaDsp(const plugdesc *plug, void *handle_, const LADSPA_Descriptor *desc_, bool mono, bool to_mono)
     : PluginDef(), desc(desc_), handle(handle_), instance(),
-      ports(new LADSPA_Data[desc->PortCount]), name_str(), pd(plug), is_activated(false) {
+      ports(new LADSPA_Data[desc->PortCount]), name_str(), dest_str(), pd(plug), is_activated(false) {
     version = PLUGINDEF_VERSION;
     id = pd->id_str.c_str();
     category = pd->category.c_str();
-    description = desc->Name;
+    dest_str = "LADSPA ";
+    dest_str += desc->Name;
+    dest_str += " by ";
+    dest_str += desc->Maker;
+    description = dest_str.c_str();
     name = desc->Name;
     set_shortname();
     set_samplerate = init;
     if (mono) {
 	mono_audio = mono_process;
     } else {
-	stereo_audio = stereo_process;
+	if (to_mono) mono_audio = to_mono_process;
+	else stereo_audio = stereo_process;
     }
     activate_plugin = activate;
     register_params = registerparam;
@@ -231,6 +246,7 @@ void plugdesc::readJSON(gx_system::JsonParser& jp) {
 	    jp.read_kv("category", category) ||
 	    jp.read_kv("quirks", quirks) ||
 	    jp.read_kv("add_wet_dry", add_wet_dry) ||
+	    jp.read_kv("stereo_to_mono", stereo_to_mono) ||
 	    jp.read_kv("master_idx", master_idx) ||
 	    jp.read_kv("master_label", master_label) ||
 	    jp.read_kv("id_str", id_str)) {
@@ -259,6 +275,7 @@ void plugdesc::writeJSON(gx_system::JsonWriter& jw) {
     jw.write_kv("category", category);
     jw.write_kv("quirks", quirks);
     jw.write_kv("add_wet_dry", add_wet_dry);
+    jw.write_kv("stereo_to_mono", stereo_to_mono);
     jw.write_kv("master_idx", master_idx);
     jw.write_kv("master_label", master_label);
     jw.write_kv("id_str", id_str);
@@ -376,6 +393,49 @@ void LadspaDsp::mono_process(int count, float *input, float *output, PluginDef *
     }
 }
 
+void LadspaDsp::up_to_stereo(int count, float *input0, float *output0, float *output1) {
+    memcpy(output0, input0, count * sizeof(float));
+    memcpy(output1, input0, count * sizeof(float));
+}
+
+void LadspaDsp::down_to_mono(int count, float *input0, float *input1, float *output0) {
+	for (int i=0; i<count; i++) {
+		output0[i] = 0.5 * (input0[i] + input1[i]);
+	}
+}
+
+void LadspaDsp::to_mono_process(int count, float *input, float *output, PluginDef *plugin) {
+    LadspaDsp& self = *static_cast<LadspaDsp*>(plugin);
+    assert(self.is_activated);
+    if (self.pd->add_wet_dry) {
+	float wet_out[count];
+	float inputs[count];
+	float inputs1[count];
+	float outputs[count];
+	float outputs1[count];
+	self.up_to_stereo(count,input,inputs, inputs1);
+	self.connect(LADSPA_PORT_INPUT, 0, inputs);
+	self.connect(LADSPA_PORT_INPUT, 1, inputs1);
+	self.connect(LADSPA_PORT_INPUT, 0, outputs);
+	self.connect(LADSPA_PORT_INPUT, 1, outputs1);
+    self.desc->run(self.instance, count);
+	self.down_to_mono(count,outputs,outputs1,wet_out);
+	self.mono_dry_wet(count, input, wet_out, output);
+    } else {
+	float inputs[count];
+	float inputs1[count];
+	float outputs[count];
+	float outputs1[count];
+	self.up_to_stereo(count,input,inputs, inputs1);
+	self.connect(LADSPA_PORT_INPUT, 0, inputs);
+	self.connect(LADSPA_PORT_INPUT, 1, inputs1);
+	self.connect(LADSPA_PORT_INPUT, 0, outputs);
+	self.connect(LADSPA_PORT_INPUT, 1, outputs1);
+    self.desc->run(self.instance, count);
+	self.down_to_mono(count,outputs,outputs1,output);
+    }
+}
+
 inline void LadspaDsp::stereo_dry_wet(int count, float *input0, float *input1, float *input2, float *input3, float *output0, float *output1)
 {
 	double 	fSlow0 = (0.01 * dry_wet);
@@ -597,6 +657,8 @@ int LadspaDsp::uiloader(const UiBuilder& b, int form) {
 	    row +=1;
 	}
 	const char *p1 = self.desc->PortNames[(*it)->index];
+	if (!(*it)->name.empty())
+	p1 = (*it)->name.c_str();
 	Glib::ustring trim = TrimEffectLabel(p1, 4);
 	const char *p = trim.c_str();
 	std::string id = self.make_id(**it);
@@ -675,6 +737,7 @@ class Lv2Dsp: public PluginDef {
 private:
     static void init(unsigned int samplingFreq, PluginDef *plugin);
     static void mono_process(int count, float *input, float *output, PluginDef *plugin);
+    static void to_mono_process(int count, float *input, float *output, PluginDef *plugin);
     static void stereo_process(int count, float *input1, float *input2, float *output1, float *output2, PluginDef *plugin);
     static int activate(bool start, PluginDef *plugin);
     static int registerparam(const ParamReg& reg);
@@ -687,6 +750,7 @@ private:
     LilvInstance* instance;
     LADSPA_Data *ports;
     Glib::ustring name_str;
+    Glib::ustring dest_str;
     const plugdesc *pd;
     bool is_activated;
     void connect(const LilvNode* tp, int i, float *v);
@@ -696,8 +760,10 @@ private:
     std::string idd;
     inline void mono_dry_wet(int count, float *input0, float *input1, float *output0);
     inline void stereo_dry_wet(int count, float *input0, float *input1, float *input2, float *input3, float *output0, float *output1);
+    inline void down_to_mono(int count, float *input0, float *input1, float *output0);
+    inline void up_to_stereo(int count, float *input0, float *output0, float *output1);
     std::string make_id(const paradesc& p);
-    Lv2Dsp(const plugdesc *plug, const LilvPlugin* plugin_, const LadspaLoader& loader_, bool mono);
+    Lv2Dsp(const plugdesc *plug, const LilvPlugin* plugin_, const LadspaLoader& loader_, bool mono, bool to_mono);
     ~Lv2Dsp();
 public:
     static Lv2Dsp *create(const plugdesc *plug, const LadspaLoader& loader);
@@ -718,10 +784,12 @@ Lv2Dsp *Lv2Dsp::create(const plugdesc *plug, const LadspaLoader& loader) {
     int num_controls = lilv_plugin_get_num_ports_of_class(plugin, loader.lv2_ControlPort, 0);
 
     bool mono;
+    bool to_mono = false;
     if (num_inputs == 1 && num_outputs == 1) {
 	mono = true;
     } else if (num_inputs == 2 && num_outputs == 2) {
 	mono = false;
+	if (plug->stereo_to_mono) to_mono = true;
     } else {
 	LilvNode *nm = lilv_plugin_get_name(plugin);
 	gx_print_error(
@@ -731,7 +799,7 @@ Lv2Dsp *Lv2Dsp::create(const plugdesc *plug, const LadspaLoader& loader) {
 	lilv_node_free(nm);
 	return NULL;
     }
-    Lv2Dsp* self = new Lv2Dsp(plug, plugin, loader, mono);
+    Lv2Dsp* self = new Lv2Dsp(plug, plugin, loader, mono, to_mono);
     int desk_controls = 0;
     for (std::vector<paradesc*>::const_iterator it = self->pd->names.begin(); it != self->pd->names.end(); ++it, ++desk_controls) ;
     if (num_controls != desk_controls) {
@@ -741,26 +809,38 @@ Lv2Dsp *Lv2Dsp::create(const plugdesc *plug, const LadspaLoader& loader) {
 		_("LV2 plugin %1 has changed it's ports, this may result in errors!!\nPlease go to the LADSPA/LV2 loader and select %1\nSelect 'Show Details' and press 'Restore Defaults'\nUn-load %1 (un-tick the box) and press 'save'.\nAfter this you could re-load %1 with it's new ports"),
 		lilv_node_as_string(nm)));
 	lilv_node_free(nm);
-	PluginDef& pl = *static_cast<PluginDef*>(self);
-	pl.flags |=PGNI_NEED_UPDATE;
 	}    
+    PluginDef& pl = *static_cast<PluginDef*>(self);
+    pl.flags |=PGNI_IS_LV2;
     return self;
 }
 
-Lv2Dsp::Lv2Dsp(const plugdesc *plug, const LilvPlugin* plugin_, const LadspaLoader& loader_, bool mono)
+Lv2Dsp::Lv2Dsp(const plugdesc *plug, const LilvPlugin* plugin_, const LadspaLoader& loader_, bool mono, bool to_mono)
     : PluginDef(), loader(loader_), plugin(plugin_), name_node(lilv_plugin_get_name(plugin_)), instance(),
-      ports(new LADSPA_Data[lilv_plugin_get_num_ports(plugin_)]), name_str(), pd(plug), is_activated(false) {
+      ports(new LADSPA_Data[lilv_plugin_get_num_ports(plugin_)]), name_str(), dest_str(), pd(plug), is_activated(false) {
     version = PLUGINDEF_VERSION;
     id = pd->id_str.c_str();
     category = pd->category.c_str();
-    description = lilv_node_as_string(name_node);
+    dest_str = "LV2 ";
+    dest_str += lilv_node_as_string(name_node);
+    LilvNode *nd = lilv_plugin_get_author_name(plugin);
+    if (!nd) {
+        nd = lilv_plugin_get_project(plugin);
+    }
+    if (nd) {
+        dest_str += " by ";
+        dest_str += lilv_node_as_string(nd);
+    }
+    lilv_node_free(nd);
+    description = dest_str.c_str();
     name = lilv_node_as_string(name_node);
     set_shortname();
     set_samplerate = init;
     if (mono) {
 	mono_audio = mono_process;
     } else {
-	stereo_audio = stereo_process;
+	if (to_mono) mono_audio = to_mono_process;
+	else stereo_audio = stereo_process;
     }
     activate_plugin = activate;
     register_params = registerparam;
@@ -884,6 +964,49 @@ void Lv2Dsp::mono_process(int count, float *input, float *output, PluginDef *plu
     }
 }
 
+void Lv2Dsp::up_to_stereo(int count, float *input0, float *output0, float *output1) {
+    memcpy(output0, input0, count * sizeof(float));
+    memcpy(output1, input0, count * sizeof(float));
+}
+
+void Lv2Dsp::down_to_mono(int count, float *input0, float *input1, float *output0) {
+	for (int i=0; i<count; i++) {
+		output0[i] = 0.5 * (input0[i] + input1[i]);
+	}
+}
+
+void Lv2Dsp::to_mono_process(int count, float *input, float *output, PluginDef *plugin) {
+    Lv2Dsp& self = *static_cast<Lv2Dsp*>(plugin);
+    assert(self.is_activated);
+    if (self.pd->add_wet_dry) {
+	float wet_out[count];
+	float inputs[count];
+	float inputs1[count];
+	float outputs[count];
+	float outputs1[count];
+	self.up_to_stereo(count,input,inputs, inputs1);
+	self.connect(self.loader.lv2_InputPort, 0, inputs);
+	self.connect(self.loader.lv2_InputPort, 1, inputs1);
+	self.connect(self.loader.lv2_OutputPort, 0, outputs);
+	self.connect(self.loader.lv2_OutputPort, 1, outputs1);
+	lilv_instance_run(self.instance, count);
+	self.down_to_mono(count,outputs,outputs1,wet_out);
+	self.mono_dry_wet(count, input, wet_out, output);
+    } else {
+	float inputs[count];
+	float inputs1[count];
+	float outputs[count];
+	float outputs1[count];
+	self.up_to_stereo(count,input,inputs, inputs1);
+	self.connect(self.loader.lv2_InputPort, 0, inputs);
+	self.connect(self.loader.lv2_InputPort, 1, inputs1);
+	self.connect(self.loader.lv2_OutputPort, 0, outputs);
+	self.connect(self.loader.lv2_OutputPort, 1, outputs1);
+	lilv_instance_run(self.instance, count);
+	self.down_to_mono(count,outputs,outputs1,output);
+    }
+}
+
 inline void Lv2Dsp::stereo_dry_wet(int count, float *input0, float *input1, float *input2, float *input3, float *output0, float *output1)
 {
 	double 	fSlow0 = (0.01 * dry_wet);
@@ -1026,7 +1149,11 @@ int Lv2Dsp::uiloader(const UiBuilder& b, int form) {
 	}
 	const LilvPort* port = lilv_plugin_get_port_by_index(self.plugin, (*it)->index);
 	LilvNode* nm_node = lilv_port_get_name(self.plugin, port);
-	const char *p = lilv_node_as_string(nm_node);
+	const char *p1 = lilv_node_as_string(nm_node);
+	if (!(*it)->name.empty())
+	p1 = (*it)->name.c_str();
+	Glib::ustring trim = TrimEffectLabel(p1, 4);
+	const char *p = trim.c_str();
 	std::string id = self.make_id(**it);
 	if ((row == 1 && rows == 1 ) || (row >1 && rows >1 )) {
 		b.set_next_flags(UI_LABEL_INVERSE);
@@ -1221,6 +1348,11 @@ void LadspaLoader::read_module_config(const std::string& filename, plugdesc *p)
     p->quirks = jp.current_value_int();
     jp.next(gx_system::JsonParser::value_number);
     p->add_wet_dry= jp.current_value_int();
+    // new monobox for stereo plugs
+    if (jp.peek() == gx_system::JsonParser::value_number) {
+        jp.next(gx_system::JsonParser::value_number);
+        p->stereo_to_mono= jp.current_value_int();
+    }
     jp.next(gx_system::JsonParser::begin_array);
     while (jp.peek() != gx_system::JsonParser::end_array) {
 	paradesc *para = new paradesc;
