@@ -137,9 +137,12 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
     pmap.reg_par("ui.live_play_switcher", "Liveplay preset mode" , (bool*)0, false, false)->setSavable(false);
     pmap.reg_par("ui.racktuner", N_("Tuner on/off"), (bool*)0, false, false);
     pmap.reg_non_midi_par("system.show_tuner", (bool*)0, false);
+    pmap.reg_non_midi_par("system.stick_tuner", (bool*)0, false);
     pmap.reg_non_midi_par("system.midi_in_preset", (bool*)0, false, false);
     pmap.reg_par_non_preset("ui.liveplay_brightness", "?liveplay_brightness", 0, 1.0, 0.5, 1.0, 0.01);
     pmap.reg_par_non_preset("ui.liveplay_background", "?liveplay_background", 0, 0.8, 0.0, 1.0, 0.01);
+    pmap.reg_par("engine.next_preset", "Switch to next preset" , (bool*)0, false, false)->setSavable(false);
+    pmap.reg_par("engine.previus_preset", "Switch to previous preset" , (bool*)0, false, false)->setSavable(false);
     BoolParameter& p = pmap.reg_par(
 	"engine.mute", "Mute", 0, engine.get_state() == gx_engine::kEngineOff
 	)->getBool();
@@ -160,6 +163,20 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
     ip.signal_changed().connect(
 	sigc::mem_fun(this, &GxMachine::set_jack_insert));
 
+    gx_preset::UnitPresetList presetnames;
+    plugin_preset_list_load(pluginlist_lookup_plugin("seq")->get_pdef(), presetnames);
+    for (gx_preset::UnitPresetList::iterator i = presetnames.begin(); i != presetnames.end(); ++i) {
+        if (!i->name.empty()) {
+            Glib::ustring id = "seq." + i->name;
+            Glib::ustring tb = "switch to preset " + i->name;
+            BoolParameter& sp = pmap.reg_par(
+              id, tb, (bool*)0, false, false)->getBool();
+            sp.setSavable(false);
+            sp.signal_changed().connect(sigc::hide(
+               sigc::bind(sigc::bind(sigc::bind(sigc::mem_fun(this, &GxMachine::plugin_preset_list_set_on_idle), i->name), false),pluginlist_lookup_plugin("seq")->get_pdef())));
+        }
+    }
+
 #ifndef NDEBUG
     // ------ time measurement (debug) ------
     gx_system::add_time_measurement();
@@ -177,6 +194,10 @@ GxMachine::GxMachine(gx_system::CmdlineOptions& options_):
     engine.midiaudiobuffer.signal_jack_load_change().connect(
 	sigc::mem_fun(this, &GxMachine::on_jack_load_change));
     switch_bank = settings.get_current_bank();
+    pmap["engine.next_preset"].signal_changed_bool().connect(
+	sigc::mem_fun(this, &GxMachine::process_next_preset_switch));
+    pmap["engine.previus_preset"].signal_changed_bool().connect(
+	sigc::mem_fun(this, &GxMachine::process_previus_preset_switch));
 
 }
 
@@ -189,6 +210,17 @@ GxMachine::~GxMachine() {
 #endif
 }
 
+void GxMachine::insert_param(Glib::ustring group, Glib::ustring name) {
+    
+    Glib::ustring tb = "switch to preset " + name;
+    Glib::ustring id = group + "." + name;
+    BoolParameter& sp = pmap.reg_par(
+      id, tb, (bool*)0, false, false)->getBool();
+    sp.setSavable(false);
+    sp.signal_changed().connect(sigc::hide(
+      sigc::bind(sigc::bind(sigc::bind(sigc::mem_fun(this, &GxMachine::plugin_preset_list_set_on_idle), name), false),pluginlist_lookup_plugin("seq")->get_pdef())));
+}
+
 void GxMachine::on_jack_load_change() {
     gx_engine::MidiAudioBuffer::Load l = engine.midiaudiobuffer.jack_load_status();
     if (l == gx_engine::MidiAudioBuffer::load_low && !engine.midiaudiobuffer.get_midistat()) {
@@ -203,6 +235,36 @@ void GxMachine::edge_toggle_tuner(bool v) {
     }
 }
 
+void GxMachine::next_preset_switch() {
+    gx_system::PresetFileGui *f= get_current_bank_file();
+    int idx = f->get_index(get_current_name());
+    if (idx+1 < f->size()) load_preset(f, f->get_name(idx+1));
+    else load_preset(f, f->get_name(0));
+}
+
+void GxMachine::previus_preset_switch() {
+    gx_system::PresetFileGui *f= get_current_bank_file();
+    int idx = f->get_index(get_current_name());
+    if (idx-1 > -1) load_preset(f, f->get_name(idx-1));
+    else load_preset(f, f->get_name(f->size()-1));
+}
+
+void GxMachine::process_next_preset_switch(bool s) {
+    if(s) {
+        Glib::signal_idle().connect_once(
+          sigc::mem_fun(this, &GxMachine::next_preset_switch));
+        set_parameter_value("engine.next_preset",false);
+    }
+}
+
+void GxMachine::process_previus_preset_switch(bool s) {
+    if(s) {
+        Glib::signal_idle().connect_once(
+          sigc::mem_fun(this, &GxMachine::previus_preset_switch));
+        set_parameter_value("engine.previus_preset",false);
+    }
+}
+
 void GxMachine::do_program_change(int pgm) {
     Glib::ustring bank = settings.get_current_bank();
     if ((bank != switch_bank) && !switch_bank.empty()) {
@@ -542,6 +604,16 @@ void GxMachine::plugin_preset_list_set(const PluginDef *pdef, bool factory, cons
     settings.plugin_preset_list_set(pdef, factory, name);
 }
 
+void GxMachine::plugin_preset_list_sync_set(const PluginDef *pdef, bool factory, const Glib::ustring& name) {
+    settings.plugin_preset_list_sync_set(pdef, factory, name);
+}
+
+void GxMachine::plugin_preset_list_set_on_idle(const PluginDef *pdef, bool factory, const Glib::ustring& name) {
+    Glib::signal_idle().connect_once(
+      sigc::bind(sigc::bind(sigc::bind(sigc::mem_fun(this, &GxMachine::plugin_preset_list_sync_set),name),factory),pdef));
+
+}
+
 void GxMachine::plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name) {
     settings.plugin_preset_list_save(pdef, name);
 }
@@ -949,7 +1021,7 @@ inline void debug_trace_param(Parameter *p) {
     } else if (dynamic_cast<JConvParameter*>(p) != 0) {
 	cerr << dynamic_cast<JConvParameter*>(p)->get_value().getFullIRPath();
     } else if (dynamic_cast<SeqParameter*>(p) != 0) {
-	cerr << dynamic_cast<SeqParameter*>(p)->get_value();
+	cerr << "SeqParameter";
     } else {
 	assert(false);
     }
@@ -1895,6 +1967,38 @@ void GxMachineRemote::tuner_switcher_toggle(bool v) {
 }
 
 // preset
+
+void GxMachineRemote::next_preset_switch() {
+    gx_system::PresetFileGui *f= get_current_bank_file();
+    int idx = f->get_index(get_current_name());
+    if (idx+1 < f->size()) load_preset(f, f->get_name(idx+1));
+    else load_preset(f, f->get_name(0));
+}
+
+void GxMachineRemote::previus_preset_switch() {
+    gx_system::PresetFileGui *f= get_current_bank_file();
+    int idx = f->get_index(get_current_name());
+    if (idx-1 > -1) load_preset(f, f->get_name(idx-1));
+    else load_preset(f, f->get_name(f->size()-1));
+}
+
+void GxMachineRemote::process_next_preset_switch(bool s) {
+    if(s) {
+        Glib::signal_idle().connect_once(
+          sigc::mem_fun(this, &GxMachineRemote::next_preset_switch));
+        set_parameter_value("engine.next_preset",false);
+    }
+}
+
+void GxMachineRemote::process_previus_preset_switch(bool s) {
+    if(s) {
+        Glib::signal_idle().connect_once(
+          sigc::mem_fun(this, &GxMachineRemote::previus_preset_switch));
+        set_parameter_value("engine.previus_preset",false);
+    }
+}
+
+
 bool GxMachineRemote::setting_is_preset() {
     return (!get_current_bank().empty());
 }
@@ -1947,7 +2051,6 @@ void GxMachineRemote::load_preset(gx_system::PresetFileGui *pf, const Glib::ustr
 void GxMachineRemote::load_online_presets() {
     START_NOTIFY(set_online_presets);
     SEND();
-    // FIXME
 }
 
 void GxMachineRemote::loadstate() {
@@ -1963,7 +2066,8 @@ int GxMachineRemote::get_bank_index(const Glib::ustring& bank) {
 }
 
 void GxMachineRemote::create_default_scratch_preset() {
-    /* noop */
+    START_NOTIFY(create_default_scratch_preset);
+    SEND();
 }
 
 void GxMachineRemote::set_statefilename(const std::string& fn) {
@@ -2001,6 +2105,19 @@ void GxMachineRemote::plugin_preset_list_set(const PluginDef *pdef, bool factory
     SEND();
 }
 
+void GxMachineRemote::plugin_preset_list_sync_set(const PluginDef *pdef, bool factory, const Glib::ustring& name) {
+    START_NOTIFY(plugin_preset_list_sync_set);
+    jw->write(pdef->id);
+    jw->write(factory);
+    jw->write(name);
+    SEND();
+}
+
+void GxMachineRemote::plugin_preset_list_set_on_idle(const PluginDef *pdef, bool factory, const Glib::ustring& name) {
+    Glib::signal_idle().connect_once(
+      sigc::bind(sigc::bind(sigc::bind(sigc::mem_fun(this, &GxMachineRemote::plugin_preset_list_sync_set),name),factory),pdef));
+}
+
 void GxMachineRemote::plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name) {
     START_NOTIFY(plugin_preset_list_save);
     jw->write(pdef->id);
@@ -2293,6 +2410,26 @@ Parameter& GxMachineRemote::get_parameter(const std::string& id) {
     return pmap[id];
 }
 
+// special case for DrumSequencer: register parameter for midi cc connection
+void GxMachineRemote::insert_param(Glib::ustring group, Glib::ustring name) {
+    Glib::ustring id = group + "." + name;
+    Glib::ustring tb = "switch to preset " + name;
+    START_NOTIFY(insert_param);
+    jw->write(id);
+    jw->write(tb);
+    SEND();
+    if (!pmap.hasId(id)) {
+        if (!gx_engine::get_group_table().group_exist(group))
+            gx_engine::get_group_table().insert(group,"Drumsequencer");
+        BoolParameter& sp = pmap.reg_par(
+          id, tb, (bool*)0, false, false)->getBool();
+        sp.setSavable(false);
+    }
+    if (pmap.hasId(id))
+        pmap[id].signal_changed_bool().connect(sigc::hide(
+          sigc::bind(sigc::bind(sigc::bind(sigc::mem_fun(this, &GxMachineRemote::plugin_preset_list_set_on_idle), name), false),pluginlist_lookup_plugin("seq")->get_pdef())));
+}
+
 void GxMachineRemote::set_init_values() {
     for (ParamMap::iterator i = pmap.begin(); i != pmap.end(); ++i) {
 	Parameter *p = i->second;
