@@ -68,6 +68,7 @@ class ParameterGroups {
 	debug_check(group_is_new, id);
 	groups.insert(pair<string, string>(id, group));
     }
+    bool group_exist(const string& id);
     inline void erase(const string& id) {
 #ifndef NDEBUG // avoid unused variable warning in release mode
 	size_t n = groups.erase(id);
@@ -652,7 +653,8 @@ class MidiStandardControllers {
         modstring(): name(""), modified(false), std(0) {}
     };
     map<int, modstring> m;
-
+    string midi_to_note(int ctr);
+    string ctr_desc(int ctr);
  public:
     MidiStandardControllers();
     const string operator[](int ctr) { return m[ctr].name; }
@@ -685,7 +687,7 @@ class MidiController {
     bool hasParameter(const Parameter& p) const { return *param == p; }
     Parameter& getParameter() const { return *param; }
     static MidiController *readJSON(gx_system::JsonParser& jp, ParamMap& param);
-    bool set_midi(int n, int last_value); //RT
+    bool set_midi(int n, int last_value, bool update); //RT
     bool set_bpm(int n, int last_value); //RT
     bool set_trans(int n, int last_value); //RT
     void set(float v, float high) { param->midi_set(v, high, _lower, _upper); }
@@ -721,7 +723,7 @@ public:
 
 class ControllerArray: public vector<midi_controller_list> {
 public:
-    enum { array_size = 128 };
+    enum { array_size = 328 };
     ControllerArray(): vector<midi_controller_list>(array_size) {}
     ~ControllerArray() {}
     void writeJSON(gx_system::JsonWriter& jw) const;
@@ -747,6 +749,7 @@ private:
     Glib::Dispatcher       pgm_chg;
     Glib::Dispatcher       mute_chg;
     Glib::Dispatcher       bank_chg;
+    Glib::Dispatcher       val_chg;
     sigc::signal<void>     changed;
     sigc::signal<void,int> new_program;
     sigc::signal<void,int> new_mute_state;
@@ -756,6 +759,7 @@ private:
     void               on_pgm_chg();
     void               on_mute_chg();
     void               on_bank_chg();
+    void               on_val_chg();
     bool check_midi_values();
 public:
     MidiControllerList();
