@@ -122,6 +122,8 @@ public:
     virtual void save_to_state(bool preserve_preset=false) = 0;
     virtual void plugin_preset_list_load(const PluginDef *pdef, gx_preset::UnitPresetList &presetnames) = 0;
     virtual void plugin_preset_list_set(const PluginDef *pdef, bool factory, const Glib::ustring& name) = 0;
+    virtual void plugin_preset_list_sync_set(const PluginDef *pdef, bool factory, const Glib::ustring& name) = 0;
+    virtual void plugin_preset_list_set_on_idle(const PluginDef *pdef, bool factory, const Glib::ustring& name) = 0;
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name) = 0;
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name) = 0;
     virtual void disable_autosave(bool v) = 0;
@@ -149,11 +151,17 @@ public:
     virtual void bank_save() = 0;
     virtual void pf_save(gx_system::PresetFileGui& pf, const Glib::ustring& name) = 0;
 
+    virtual void next_preset_switch() = 0;
+    virtual void previus_preset_switch() = 0;
+    virtual void process_next_preset_switch(bool s) = 0;
+    virtual void process_previus_preset_switch(bool s) = 0;
+
     // jack
     virtual gx_jack::GxJack *get_jack() = 0;
     virtual void set_jack_insert(bool v) = 0;
     // pmap
     virtual Parameter& get_parameter(const std::string& id) = 0;
+    virtual void insert_param(Glib::ustring group, Glib::ustring name) = 0;
     virtual void set_init_values() = 0;
     virtual bool parameter_hasId(const char *p) = 0;
     virtual bool parameter_hasId(const std::string& id) = 0;
@@ -233,6 +241,7 @@ private:
     void reset_switch_bank();
     int get_bank_num(Glib::ustring num);
     void set_mute_state(int mute);
+    volatile int block;
     void do_program_change(int pgm);
     void do_bank_change(int pgm);
     void edge_toggle_tuner(bool v);
@@ -305,6 +314,8 @@ public:
     virtual void save_to_state(bool preserve_preset=false);
     virtual void plugin_preset_list_load(const PluginDef *pdef, gx_preset::UnitPresetList &presetnames);
     virtual void plugin_preset_list_set(const PluginDef *pdef, bool factory, const Glib::ustring& name);
+    virtual void plugin_preset_list_sync_set(const PluginDef *pdef, bool factory, const Glib::ustring& name);
+    virtual void plugin_preset_list_set_on_idle(const PluginDef *pdef, bool factory, const Glib::ustring& name);
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name);
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name);
     virtual void disable_autosave(bool v);
@@ -332,12 +343,18 @@ public:
     virtual void bank_save();
     virtual void pf_save(gx_system::PresetFileGui& pf, const Glib::ustring& name);
 
+    virtual void next_preset_switch();
+    virtual void previus_preset_switch();
+    virtual void process_next_preset_switch(bool s);
+    virtual void process_previus_preset_switch(bool s);
+
     // jack
     virtual gx_jack::GxJack *get_jack();
     virtual void set_jack_insert(bool v);
     // pmap
     virtual Parameter& get_parameter(const char *p);
     virtual Parameter& get_parameter(const std::string& id);
+    virtual void insert_param(Glib::ustring group, Glib::ustring name);
     virtual void set_init_values();
     virtual bool parameter_hasId(const char *p);
     virtual bool parameter_hasId(const std::string& id);
@@ -485,6 +502,8 @@ public:
     virtual void save_to_state(bool preserve_preset=false);
     virtual void plugin_preset_list_load(const PluginDef *pdef, gx_preset::UnitPresetList &presetnames);
     virtual void plugin_preset_list_set(const PluginDef *pdef, bool factory, const Glib::ustring& name);
+    virtual void plugin_preset_list_sync_set(const PluginDef *pdef, bool factory, const Glib::ustring& name);
+    virtual void plugin_preset_list_set_on_idle(const PluginDef *pdef, bool factory, const Glib::ustring& name);
     virtual void plugin_preset_list_save(const PluginDef *pdef, const Glib::ustring& name);
     virtual void plugin_preset_list_remove(const PluginDef *pdef, const Glib::ustring& name);
     virtual void disable_autosave(bool v);
@@ -512,12 +531,18 @@ public:
     virtual void bank_save();
     virtual void pf_save(gx_system::PresetFileGui& pf, const Glib::ustring& name);
 
+    virtual void next_preset_switch();
+    virtual void previus_preset_switch();
+    virtual void process_next_preset_switch(bool s);
+    virtual void process_previus_preset_switch(bool s);
+
     // jack
     virtual gx_jack::GxJack *get_jack();
     virtual void set_jack_insert(bool v);
     // pmap
     virtual Parameter& get_parameter(const char *p);
     virtual Parameter& get_parameter(const std::string& id);
+    virtual void insert_param(Glib::ustring group, Glib::ustring name);
     virtual void set_init_values();
     virtual bool parameter_hasId(const char *p);
     virtual bool parameter_hasId(const std::string& id);
